@@ -12,9 +12,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
-import gevent
-from gevent import monkey;  monkey.patch_all()
 import datetime
 import grp
 import json
